km3modules.k40.ResetTwofoldCounts
=================================

.. currentmodule:: km3modules.k40

.. autoclass:: ResetTwofoldCounts

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ResetTwofoldCounts.__init__
      ~ResetTwofoldCounts.add
      ~ResetTwofoldCounts.configure
      ~ResetTwofoldCounts.expose
      ~ResetTwofoldCounts.finish
      ~ResetTwofoldCounts.get
      ~ResetTwofoldCounts.pre_finish
      ~ResetTwofoldCounts.process
      ~ResetTwofoldCounts.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ResetTwofoldCounts.name
   
   